import { Icon } from '@iconify/react/dist/iconify.js';
import { FC, useMemo } from 'react';
import { SharedIconProps } from './shared-props';

type IconBatteryProps = SharedIconProps & {
  level?: number | null;
};

const IconBattery: FC<IconBatteryProps> = ({
  height = 24,
  aspect = 1,
  stroke = 0.5,
  level = null,
}) => {
  const width = useMemo(() => height * aspect, [height, aspect]);
  const batteryIcon = useMemo(() => {
    if (level !== null && level >= 90) {
      return 'material-symbols-light:battery-full';
    } else if (level !== null && level >= 80) {
      return 'material-symbols-light:battery-6-bar';
    } else if (level !== null && level >= 70) {
      return 'material-symbols-light:battery-5-bar';
    } else if (level !== null && level >= 50) {
      return 'material-symbols-light:battery-4-bar';
    } else if (level !== null && level >= 30) {
      return 'material-symbols-light:battery-3-bar';
    } else if (level !== null && level >= 20) {
      return 'material-symbols-light:battery-2-bar';
    } else if (level !== null && level >= 10) {
      return 'material-symbols-light:battery-1-bar';
    } else if (level !== null && level >= 0) {
      return 'material-symbols-light:battery-0-bar';
    } else {
      return 'material-symbols-light:battery-error';
    }
  }, [level]);

  return <Icon icon={batteryIcon} width={width} height={height} stroke={stroke} />;
};

export default IconBattery;
